"""Imports main function"""
from .pddns import run

__author__ = "Cyb3r Jak3"
__version__ = "v2.2.0"

__all__ = ["run", "__author__", "__version__"]
